// Sample implementation for a minimal Dark Engine FM Selector

/* This program is free software. It comes without any warranty, to
 * the extent permitted by applicable law. You can redistribute it
 * and/or modify it under the terms of the Do What The Fuck You Want
 * To Public License, Version 2, as published by Sam Hocevar. See
 * http://sam.zoy.org/wtfpl/COPYING for more details.
 */

#include "fmsel.h"
#include <string.h>
#include <FL/Fl.H>
#include <FL/Fl_Widget.H>
#include <FL/Fl_Ask.H>

#ifndef NULL
#define NULL 0
#endif


static eFMSelReturn appReturn = kSelFMRet_Cancel;
static sFMSelectorData *pFMSelData = NULL;

static void OnOK(Fl_Widget *o, void *p);
static void OnCancel(Fl_Widget *o, void *p);
static void OnExit(Fl_Widget *o, void *p);


// include FLUID autogenerated code
#include "fl_mainwnd.cpp.h"


/////////////////////////////////////////////////////////////////////
// MAIN WINDOW

static void OnOK(Fl_Widget *o, void *p)
{
	int sel = pFMList->value();

	if (!sel)
	{
		fl_message("Please make a selection");
		return;
	}

	if (sel == 1)
	{
		*pFMSelData->sName = 0;
	}
	else
	{
		const char *s = pFMList->text(sel);

		if (s && *s)
		{
			char buf[256];

			strncpy(buf, s, sizeof(buf));
			buf[sizeof(buf)-1] = 0;

			char *q = buf + strlen(buf) - 1;
			if (*q == '/' || *q == '\\') *q = 0;

			if (*buf)
			{
				strncpy(pFMSelData->sName, buf, pFMSelData->nMaxNameLen);
				pFMSelData->sName[pFMSelData->nMaxNameLen-1] = 0;

				appReturn = kSelFMRet_OK;
			}
		}
	}

	pMainWnd->hide();
}

static void OnCancel(Fl_Widget *o, void *p)
{
	pMainWnd->hide();
}

static void OnExit(Fl_Widget *o, void *p)
{
	appReturn = kSelFMRet_ExitGame;
	pMainWnd->hide();
}


static void InitControls()
{
	pMainWnd->label(pFMSelData->sGameVersion);

	// center on desktop
	pMainWnd->position(
		Fl::x() + ((Fl::w() - pMainWnd->w()) / 2),
		Fl::y() + ((Fl::h() - pMainWnd->h()) / 2)
		);

	pFMList->filetype(Fl_File_Browser::DIRECTORIES);
	pFMList->type(FL_HOLD_BROWSER);
	pFMList->load(pFMSelData->sRootPath);
}


/////////////////////////////////////////////////////////////////////
// FM SEL API

extern "C" int FMSELAPI SelectFM(sFMSelectorData *data)
{
	if (!data || data->nStructSize < sizeof(sFMSelectorData))
	{
		return kSelFMRet_Cancel;
	}

	pFMSelData = data;

	Fl::scheme("gtk+");

    MakeWindow();

	if (pMainWnd)
	{
		InitControls();

		pMainWnd->show();

		Fl::run();

		return appReturn;
	}

	return kSelFMRet_Cancel;
}
